@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2006 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2007 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,21 +22,27 @@
 # NOTE: This module is safe for 'from codes import *'
 #
 
-# Messaging Error Codes (result-code=)
 
+# GUI/Console modes
+INTERACTIVE_MODE = 0
+GUI_MODE = 1
+NON_INTERACTIVE_MODE = 2
+BROWSER_MODE = 3
+
+# Messaging Error Codes (result-code=)
 ERROR_SUCCESS = 0
 ERROR_UNKNOWN_ERROR = 1
-ERROR_DEVICE_NOT_FOUND = 2
-ERROR_INVALID_DEVICE_ID = 3
-ERROR_INVALID_DEVICE_URI = 4
+ERROR_DEVICE_NOT_FOUND = 2 # MUD: HPMUD_R_INVALID_DEVICE
+ERROR_INVALID_DEVICE_ID = 3 # MUD: HPMUD_R_INVALID_DESCRIPTOR
+ERROR_INVALID_DEVICE_URI = 4 # MUD: HPMUD_R_INVALID_URI
 ERROR_INVALID_MSG_TYPE = 5
 ERROR_INVALID_DATA_ENCODING = 6
 ERROR_INVALID_CHAR_ENCODING = 7
-ERROR_DATA_LENGTH_EXCEEDS_MAX = 8
+ERROR_DATA_LENGTH_EXCEEDS_MAX = 8 # MUD: HPMUD_R_INVALID_LENGTH
 ERROR_DATA_LENGTH_MISMATCH = 9
 ERROR_DATA_DIGEST_MISMATCH = 10
 ERROR_INVALID_JOB_ID = 11
-ERROR_DEVICE_IO_ERROR = 12
+ERROR_DEVICE_IO_ERROR = 12 # MUD: HPMUD_R_IO_ERROR
 ERROR_STRING_QUERY_FAILED = 14
 ERROR_QUERY_FAILED = 15
 ERROR_GUI_NOT_AVAILABLE = 16
@@ -44,38 +50,38 @@ ERROR_NO_CUPS_DEVICES_FOUND = 17 # deprecated
 ERROR_NO_PROBED_DEVICES_FOUND = 18
 ERROR_INVALID_BUS_TYPE = 19 # operation not supported on bus
 ERROR_BUS_TYPE_CANNOT_BE_PROBED = 20
-ERROR_DEVICE_BUSY = 21
+ERROR_DEVICE_BUSY = 21 # MUD: HPMUD_R_DEVICE_BUSY
 ERROR_NO_DATA_AVAILABLE = 22
 ERROR_INVALID_DEVICEID = 23
 ERROR_INVALID_CUPS_VERSION = 24
 ERROR_CUPS_NOT_RUNNING = 25
 ERROR_DEVICE_STATUS_NOT_AVAILABLE = 26
 ERROR_DATA_IN_SHORT_READ = 27
-ERROR_INVALID_SERVICE_NAME = 28
+ERROR_INVALID_SERVICE_NAME = 28 # MUD: HPMUD_R_INVALID_SN
 ERROR_INVALID_USER_ERROR_CODE = 29
-ERROR_ERROR_INVALID_CHANNEL_ID = 30
-ERROR_CHANNEL_BUSY = 31
+ERROR_ERROR_INVALID_CHANNEL_ID = 30 # MUD: HPMUD_R_INVALID_CHANNEL_ID
+ERROR_CHANNEL_BUSY = 31 # MUD: HPMUD_R_INVALID_STATE
 ERROR_CHANNEL_CLOSE_FAILED = 32
 ERROR_UNSUPPORTED_BUS_TYPE = 33 # bus not supported
 ERROR_DEVICE_DOES_NOT_SUPPORT_OPERATION = 34
 ERROR_INVALID_GUI_NAME = 35
 ERROR_INTERFACE_BUSY = 36
-ERROR_DEVICEOPEN_FAILED_ONE_DEVICE_ONLY = 37
-ERROR_DEVICEOPEN_FAILED_DEV_NODE_MOVED = 38
+ERROR_DEVICEOPEN_FAILED = 37 # MUD: HPMUD_R_INVALID_DEVICE_OPEN
+ERROR_INVALID_DEVNODE = 38 # MUD: HPMUD_R_INVALID_DEVICE_NODE
 ERROR_TEST_EMAIL_FAILED = 39
-#ERROR_SMTP_CONNECT_ERROR = 40
-#ERROR_SMTP_RECIPIENTS_REFUSED = 41
-#ERROR_SMTP_HELO_ERROR = 42
-#ERROR_SMTP_SENDER_REFUSED = 43
-#ERROR_SMTP_DATA_ERROR = 44
-ERROR_INVALID_HOSTNAME = 45
-ERROR_INVALID_PORT_NUMBER = 46
-ERROR_NO_CUPS_QUEUE_FOUND_FOR_DEVICE = 47
-ERROR_UNSUPPORTED_MODEL = 48
-ERROR_FAX_FILE_NOT_FOUND = 49
+ERROR_INVALID_HOSTNAME = 45 # MUD: HPMUD_R_INVALID_IP
+ERROR_INVALID_PORT_NUMBER = 46 # MUD: HPMUD_R_INVALID_IP_PORT
+ERROR_INVALID_TIMEOUT = 47 # MUD: HPMUD_R_INVALID_TIMEOUT
+ERROR_DATFILE_ERROR = 48 # MUD: HPMUD_R_DATFILE_ERROR
+ERROR_IO_TIMEOUT = 49 # MUD: HPMUD_R_IO_TIMEOUT 
 ERROR_FAX_INCOMPATIBLE_OPTIONS = 50
 ERROR_FAX_INVALID_FAX_FILE = 51
 ERROR_FAX_MUST_RUN_SENDFAX_FIRST = 52
+ERROR_FAX_PROCESSING = 53
+ERROR_FAX_READY = 54
+ERROR_NO_CUPS_QUEUE_FOUND_FOR_DEVICE = 55
+ERROR_UNSUPPORTED_MODEL = 56
+ERROR_FAX_FILE_NOT_FOUND = 57
 # --> add new codes here <--
 ERROR_UNABLE_TO_BIND_SOCKET = 95
 ERROR_UNABLE_TO_CONTACT_SERVICE = 96
@@ -84,11 +90,7 @@ ERROR_INTERNAL = 99
 # If you add new codes, also add the appropriate description
 # to g.py for exception description strings.
 # Thank you, The Management
-
-
-
-
-
+ 
 
 # Event and status codes
 # These are used for the 'status-code' returned by DeviceQuery (STATUS_*)
@@ -284,29 +286,35 @@ EVENT_CUPS_QUEUES_CHANGED = 9000 # sent by hp-setup if queues added (or removed)
 # Error states
 ERROR_STATE_CLEAR = 0        # Show icon w/o overlay
 ERROR_STATE_OK = 1           # Icon w/ "OK" overlay
-ERROR_STATE_WARNING = 2      # Icon w/ triangle "!" overlay
-ERROR_STATE_ERROR = 3        # Icon w/ circle "X" overlay
-ERROR_STATE_LOW_SUPPLIES = 4 # Icon w/ supplies overlay
-ERROR_STATE_BUSY = 5         # Icon with busy overlay
-ERROR_STATE_LOW_PAPER = 6    # Icon w/ paper low overlay
+ERROR_STATE_MAX_OK = 99
+ERROR_STATE_WARNING = 100      # Icon w/ triangle "!" overlay
+ERROR_STATE_ERROR = 101        # Icon w/ circle "X" overlay
+ERROR_STATE_LOW_SUPPLIES = 102 # Icon w/ supplies overlay
+ERROR_STATE_BUSY = 103         # Icon with busy overlay
+ERROR_STATE_LOW_PAPER = 104    # Icon w/ paper low overlay
+ERROR_STATE_PRINTING = 105
+ERROR_STATE_SCANNING = 106
+ERROR_STATE_PHOTOCARD = 107
+ERROR_STATE_FAXING = 108
+ERROR_STATE_COPYING = 109
 #end
 
 
 # Map of status/event codes to UI states
 STATUS_TO_ERROR_STATE_MAP = {
     STATUS_UNKNOWN : ERROR_STATE_CLEAR,
-    EVENT_START_PRINT_JOB : ERROR_STATE_BUSY,
+    EVENT_START_PRINT_JOB : ERROR_STATE_PRINTING,
     EVENT_END_PRINT_JOB   : ERROR_STATE_OK,
     EVENT_START_FAX_PRINT_JOB : ERROR_STATE_CLEAR,
     EVENT_END_FAX_PRINT_JOB : ERROR_STATE_OK,
     STATUS_PRINTER_IDLE : ERROR_STATE_CLEAR,
     STATUS_PRINTER_BUSY : ERROR_STATE_BUSY,
-    STATUS_PRINTER_PRINTING : ERROR_STATE_BUSY,
+    STATUS_PRINTER_PRINTING : ERROR_STATE_PRINTING,
     STATUS_PRINTER_TURNING_OFF : ERROR_STATE_BUSY,
-    STATUS_PRINTER_REPORT_PRINTING : ERROR_STATE_BUSY,
+    STATUS_PRINTER_REPORT_PRINTING : ERROR_STATE_PRINTING,
     STATUS_PRINTER_CANCELING : ERROR_STATE_BUSY,
     STATUS_PRINTER_IO_STALL : ERROR_STATE_ERROR,
-    STATUS_PRINTER_DRY_WAIT_TIME : ERROR_STATE_BUSY,
+    STATUS_PRINTER_DRY_WAIT_TIME : ERROR_STATE_PRINTING,
     STATUS_PRINTER_PEN_CHANGE : ERROR_STATE_WARNING,
     STATUS_PRINTER_OUT_OF_PAPER : ERROR_STATE_ERROR,
     STATUS_PRINTER_BANNER_EJECT : ERROR_STATE_ERROR,
@@ -355,7 +363,7 @@ STATUS_TO_ERROR_STATE_MAP = {
     STATUS_PRINTER_FUSER_ERROR : ERROR_STATE_ERROR,
     STATUS_DEVICE_UNSUPPORTED : ERROR_STATE_ERROR,
     # The following block are EVENTs because they are only
-    # recieved as events from hpiod, hp backend, etc.
+    # recieved as events from hpmud, hp backend, etc.
     # i.e., a device does not produce status codes in this range
     EVENT_ERROR_SUCCESS : ERROR_STATE_CLEAR,
     EVENT_ERROR_UNKNOWN_ERROR : ERROR_STATE_ERROR,
@@ -395,28 +403,48 @@ STATUS_TO_ERROR_STATE_MAP = {
     EVENT_ERROR_INTERFACE_BUSY : ERROR_STATE_BUSY,
     EVENT_ERROR_DEVICEOPEN_FAILED_ONE_DEVICE_ONLY : ERROR_STATE_ERROR,
     EVENT_ERROR_DEVICEOPEN_FAILED_DEV_NODE_MOVED : ERROR_STATE_ERROR,
-    
-    EVENT_START_SCAN_JOB : ERROR_STATE_BUSY,
+    # Scan
+    EVENT_START_SCAN_JOB : ERROR_STATE_SCANNING,
     EVENT_END_SCAN_JOB : ERROR_STATE_OK,
     EVENT_SCANNER_FAIL : ERROR_STATE_ERROR,
-    
-    EVENT_START_FAX_JOB : ERROR_STATE_BUSY,
+    # Fax
+    EVENT_START_FAX_JOB : ERROR_STATE_FAXING,
     EVENT_END_FAX_JOB : ERROR_STATE_OK,
     EVENT_FAX_JOB_FAIL : ERROR_STATE_ERROR,
     EVENT_FAX_JOB_CANCELED : ERROR_STATE_ERROR,
-    STATUS_FAX_TX_ACTIVE : ERROR_STATE_BUSY,
-    STATUS_FAX_RX_ACTIVE : ERROR_STATE_BUSY,
-    
-    EVENT_START_COPY_JOB : ERROR_STATE_BUSY,
+    STATUS_FAX_TX_ACTIVE : ERROR_STATE_FAXING,
+    STATUS_FAX_RX_ACTIVE : ERROR_STATE_FAXING,
+    # Copy
+    EVENT_START_COPY_JOB : ERROR_STATE_COPYING,
     EVENT_END_COPY_JOB : ERROR_STATE_OK,
     EVENT_COPY_JOB_FAIL : ERROR_STATE_ERROR,
     EVENT_COPY_JOB_CANCELED : ERROR_STATE_ERROR,
-    
-    EVENT_START_PCARD_JOB : ERROR_STATE_BUSY,
+    # PCard
+    EVENT_START_PCARD_JOB : ERROR_STATE_PHOTOCARD,
     EVENT_END_PCARD_JOB : ERROR_STATE_CLEAR,
     EVENT_PCARD_JOB_FAIL : ERROR_STATE_ERROR,
     EVENT_PCARD_UNABLE_TO_MOUNT : ERROR_STATE_ERROR,
     EVENT_PCARD_FILES_TRANSFERED : ERROR_STATE_OK,
+    
+    # Low supplies
+    STATUS_PRINTER_LOW_BLACK_INK : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_TRI_COLOR_INK : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_PHOTO_INK : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_CYAN_INK : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_MAGENTA_INK : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_YELLOW_INK : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_PHOTO_CYAN_INK : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_PHOTO_MAGENTA_INK : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_PHOTO_YELLOW_INK : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_PHOTO_GRAY_INK : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_PHOTO_BLUE_INK : ERROR_STATE_LOW_SUPPLIES,
+    
+    STATUS_PRINTER_LOW_BLACK_TONER : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_CYAN_TONER : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_MAGENTA_TONER : ERROR_STATE_LOW_SUPPLIES,
+    STATUS_PRINTER_LOW_YELLOW_TONER : ERROR_STATE_LOW_SUPPLIES,
+    # end
+    
 }
 
 
@@ -454,8 +482,8 @@ AGENT_KIND_UNKNOWN = 0x3e # (62)
 # 'type'
 AGENT_TYPE_NONE = 0
 AGENT_TYPE_BLACK = 1
-AGENT_TYPE_CMY = 2
-AGENT_TYPE_KCM = 3
+AGENT_TYPE_CMY = 2 # Tricolor
+AGENT_TYPE_KCM = 3 # Photo
 AGENT_TYPE_CYAN = 4
 AGENT_TYPE_MAGENTA = 5
 AGENT_TYPE_YELLOW = 6
@@ -464,10 +492,12 @@ AGENT_TYPE_MAGENTA_LOW = 8
 AGENT_TYPE_YELLOW_LOW = 9
 AGENT_TYPE_GGK = 10 # 2 shades of grey and black
 AGENT_TYPE_BLUE = 11
-AGENT_TYPE_KCMY_CM = 12 
+AGENT_TYPE_KCMY_CM = 12 # K/C/M/Y/LM/LC (02 pen set head)
 AGENT_TYPE_LC_LM = 13 # light cyan and light magenta
-AGENT_TYPE_Y_M = 14 # yellow and magenta
-AGENT_TYPE_C_K = 15 # cyan and black
+#AGENT_TYPE_Y_M = 14 # yellow and magenta (B9180)
+#AGENT_TYPE_C_K = 15 # cyan and black (B9180)
+AGENT_TYPE_K_Y = 14 # black and yellow (for LJ Pro)
+AGENT_TYPE_C_M = 15 # cyan and magenta (for LJ Pro)
 AGENT_TYPE_LG_PK = 16 # light grey and photo black
 AGENT_TYPE_LG = 17 # light grey
 AGENT_TYPE_G = 18 # medium grey
@@ -498,7 +528,7 @@ AGENT_LEVEL_TRIGGER_MAY_BE_LOW = 5
 AGENT_LEVEL_TRIGGER_PROBABLY_OUT = 6
 AGENT_LEVEL_TRIGGER_ALMOST_DEFINITELY_OUT = 7
 
-# "Computed" configurations
+# "Computed" configurations (2-pen products)
 AGENT_CONFIG_NONE = 0
 AGENT_CONFIG_BLACK_ONLY = 1
 AGENT_CONFIG_PHOTO_ONLY = 2
@@ -522,6 +552,7 @@ ALIGN_TYPE_DESKJET_450 = 8
 ALIGN_TYPE_9XX_NO_EDGE_ALIGN = 9
 ALIGN_TYPE_LBOW = 10
 ALIGN_TYPE_LIDIL_0_5_4 = 11
+ALIGN_TYPE_OJ_PRO = 12 # OJ Pro L7xxx
 
 # clean-types
 CLEAN_TYPE_NONE = 0
@@ -536,6 +567,7 @@ COLOR_CAL_TYPE_MALIBU_CRICK = 2
 COLOR_CAL_TYPE_STRINGRAY_LONGBOW_TORNADO = 3
 COLOR_CAL_TYPE_CONNERY = 4
 COLOR_CAL_TYPE_COUSTEAU = 5
+COLOR_CAL_TYPE_CARRIER = 6
 
 # status-types
 STATUS_TYPE_NONE = 0
@@ -549,7 +581,7 @@ STATUS_TYPE_LJ_XML = 6
 
 # status-battery-check-types
 STATUS_BATTERY_CHECK_NONE = 0
-STATUS_BATTERY_CHECK_STD = 1 # Deskjet 450
+STATUS_BATTERY_CHECK_STD = 1 # Deskjet 450/460
 
 # status-dynamic-counters-type
 STATUS_DYNAMIC_COUNTERS_NONE = 0
@@ -563,6 +595,7 @@ TECH_TYPE_MONO_INK = 1
 TECH_TYPE_COLOR_INK = 2
 TECH_TYPE_MONO_LASER = 3
 TECH_TYPE_COLOR_LASER = 4
+TECH_TYPE_COLOR_EDGELINE = 5
 
 # support-type
 SUPPORT_TYPE_NONE = 0
@@ -584,6 +617,7 @@ PCARD_TYPE_USB_MASS_STORAGE = 2
 SCAN_TYPE_NONE = 0
 SCAN_TYPE_SCL = 1
 SCAN_TYPE_PML = 2
+SCAN_TYPE_SOAP = 3
 
 # scan-styles
 SCAN_STYLE_NONE = 0
@@ -644,15 +678,20 @@ MODEL_TYPE_COLOR_LASER_AIO = 3
 MODEL_TYPE_COLOR_INKJET_AIO = 4
 MODEL_TYPE_MONO_LASER = 5
 MODEL_TYPE_MONO_LASER_AIO = 6
+MODEL_TYPE_EDGELINE = 7
 
-# 'io-mode'
+# 'io-mode' and 'io-mfp-mode'
 IO_MODE_UNI = 0
 IO_MODE_RAW = 1
-IO_MODE_MLC = 2
+#IO_MODE_NOT_USED = 2
 IO_MODE_DOT4 = 3
+IO_MODE_DOT4_PHOENIX = 4
+IO_MODE_DOT4_BRIDGE = 5
+IO_MODE_MLC_GUSHER = 6
+IO_MODE_MLC_MISER = 7
+
 
 
 
 
 
-    
