@@ -29,6 +29,7 @@ import fcntl, errno, stat, string, commands
 import cStringIO, re
 import xml.parsers.expat as expat
 import getpass
+import locale
 
 # Local
 from g import *
@@ -53,63 +54,11 @@ def Translator(frm='', to='', delete='', keep=None):
 
     return callable
 
-# For pidfile locking (must be "static" and global to the whole app)
-prv_pidfile = None
-prv_pidfile_name = ""
-
-
-def get_pidfile_lock (a_pidfile_name=""):
-    """ Call this to either lock the pidfile, or to update it after a fork()
-        Credit: Henrique M. Holschuh <hmh@debian.org>
-    """
-    global prv_pidfile
-    global prv_pidfile_name
-    if prv_pidfile_name == "":
-        try:
-            prv_pidfile_name = a_pidfile_name
-            prv_pidfile = os.fdopen(os.open(prv_pidfile_name, os.O_RDWR | os.O_CREAT, 0644), 'r+')
-            fcntl.fcntl(prv_pidfile.fileno(), fcntl.F_SETFD, fcntl.FD_CLOEXEC)
-            while 1:
-                try:
-                    fcntl.flock(prv_pidfile.fileno(), fcntl.LOCK_EX | fcntl.LOCK_NB)
-                except (OSError, IOError), e:
-                    if e.errno == errno.EINTR:
-                        continue
-                    elif e.errno == errno.EWOULDBLOCK:
-                        try:
-                            prv_pidfile.seek(0)
-                            otherpid = int(prv_pidfile.readline(), 10)
-                            sys.stderr.write ("can't lock %s, running daemon's pid may be %d\n" % (prv_pidfile_name, otherpid))
-                        except (OSError, IOError), e:
-                            sys.stderr.write ("error reading pidfile %s: (%d) %s\n" % (prv_pidfile_name, e.errno, e.strerror))
-
-                        sys.exit(1)
-                    sys.stderr.write ("can't lock %s: (%d) %s\n" % (prv_pidfile_name, e.errno, e.strerror))
-                    sys.exit(1)
-                break
-        except (OSError, IOError), e:
-            sys.stderr.write ("can't open pidfile %s: (%d) %s\n" % (prv_pidfile_name, e.errno, e.strerror))
-            sys.exit(1)
-    try:
-        prv_pidfile.seek(0)
-        prv_pidfile.write("%d\n" % (os.getpid()))
-        prv_pidfile.flush()
-        prv_pidfile.truncate()
-    except (OSError, IOError), e:
-        log.error("can't update pidfile %s: (%d) %s\n" % (prv_pidfile_name, e.errno, e.strerror))
-
-
-
 def daemonize (stdin='/dev/null', stdout='/dev/null', stderr='/dev/null'):
     """
     Credit: Jürgen Hermann, Andy Gimblett, and Noah Spurrier
             http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/66012
-
-    Proper pidfile support: Henrique M. Holschuh <hmh@debian.org>
     """
-    # Try to lock pidfile if not locked already
-    if prv_pidfile_name != '' or prv_pidfile_name != "":
-        get_pidfile_lock(prv_pidfile_name)
 
     # Do first fork.
     try:
@@ -134,11 +83,7 @@ def daemonize (stdin='/dev/null', stdout='/dev/null', stderr='/dev/null'):
         sys.stderr.write ("fork #2 failed: (%d) %s\n" % (e.errno, e.strerror))
         sys.exit(1)
 
-    if prv_pidfile_name != "":
-        get_pidfile_lock()
-
     # Now I am a daemon!
-
     # Redirect standard file descriptors.
     si = file(stdin, 'r')
     so = file(stdout, 'a+')
@@ -157,9 +102,9 @@ def to_bool_str(s, default='0'):
     """ Convert an arbitrary 0/1/T/F/Y/N string to a normalized string 0/1."""
     if isinstance(s, str) and s:
         if s[0].lower() in ['1', 't', 'y']:
-            return '1'
+            return u'1'
         elif s[0].lower() in ['0', 'f', 'n']:
-            return '0'
+            return u'0'
 
     return default
 
@@ -195,7 +140,7 @@ def walkFiles(root, recurse=True, abs_paths=False, return_folders=False, pattern
         names = os.listdir(root)
     except os.error:
         raise StopIteration
-
+        
     pattern = pattern or '*'
     pat_list = pattern.split(';')
 
@@ -213,10 +158,10 @@ def walkFiles(root, recurse=True, abs_paths=False, return_folders=False, pattern
                         except ValueError:
                             yield fullname
 
-        if os.path.islink(fullname):
-            fullname = os.path.realpath(os.readlink(fullname))
+        #if os.path.islink(fullname):
+        #    fullname = os.path.realpath(os.readlink(fullname))
 
-        if recurse and os.path.isdir(fullname) or os.path.islink(fullname):
+        if recurse and os.path.isdir(fullname): # or os.path.islink(fullname):
             for f in walkFiles(fullname, recurse, abs_paths, return_folders, pattern, path):
                 yield f
 
@@ -268,12 +213,6 @@ class TextFormatter:
         else:
             return '\n'.join(complines)
 
-    def bold(text):
-        return ''.join(["\033[1m", text, "\033[0m"])
-
-    bold = staticmethod(bold)
-
-
 class Column:
 
     def __init__(self, width=78, alignment=TextFormatter.LEFT, margin=0):
@@ -386,87 +325,8 @@ def sort_dict_by_value(d):
     backitems.sort()
     return [backitems[i][1] for i in range(0,len(backitems))]
 
-
-# Copied from Gentoo Portage output.py
-# Copyright 1998-2003 Daniel Robbins, Gentoo Technologies, Inc.
-# Distributed under the GNU Public License v2
-
-codes={}
-codes["reset"]="\x1b[0m"
-codes["bold"]="\x1b[01m"
-
-codes["teal"]="\x1b[36;06m"
-codes["turquoise"]="\x1b[36;01m"
-
-codes["fuscia"]="\x1b[35;01m"
-codes["purple"]="\x1b[35;06m"
-
-codes["blue"]="\x1b[34;01m"
-codes["darkblue"]="\x1b[34;06m"
-
-codes["green"]="\x1b[32;01m"
-codes["darkgreen"]="\x1b[32;06m"
-
-codes["yellow"]="\x1b[33;01m"
-codes["brown"]="\x1b[33;06m"
-
-codes["red"]="\x1b[31;01m"
-codes["darkred"]="\x1b[31;06m"
-
-
-def bold(text):
-    return codes["bold"]+text+codes["reset"]
-
-def white(text):
-    return bold(text)
-
-def teal(text):
-    return codes["teal"]+text+codes["reset"]
-
-def turquoise(text):
-    return codes["turquoise"]+text+codes["reset"]
-
-def darkteal(text):
-    return turquoise(text)
-
-def fuscia(text):
-    return codes["fuscia"]+text+codes["reset"]
-
-def purple(text):
-    return codes["purple"]+text+codes["reset"]
-
-def blue(text):
-    return codes["blue"]+text+codes["reset"]
-
-def darkblue(text):
-    return codes["darkblue"]+text+codes["reset"]
-
-def green(text):
-    return codes["green"]+text+codes["reset"]
-
-def darkgreen(text):
-    return codes["darkgreen"]+text+codes["reset"]
-
-def yellow(text):
-    return codes["yellow"]+text+codes["reset"]
-
-def brown(text):
-    return codes["brown"]+text+codes["reset"]
-
-def darkyellow(text):
-    return brown(text)
-
-def red(text):
-    return codes["red"]+text+codes["reset"]
-
-def darkred(text):
-    return codes["darkred"]+text+codes["reset"]
-
-
-def commafy(val):
-    return val < 0 and '-' + commafy(abs(val)) \
-        or val < 1000 and str(val) \
-        or '%s,%03d' % (commafy(val / 1000), (val % 1000))
+def commafy(val): 
+    return unicode(locale.format("%d", val, grouping=True))
 
 
 def format_bytes(s, show_bytes=False):
@@ -474,15 +334,20 @@ def format_bytes(s, show_bytes=False):
         return ''.join([commafy(s), ' B'])
     elif 1024 < s < 1048576:
         if show_bytes:
-            return ''.join([str(round(s/1024.0, 1)) , ' KB (',  commafy(s), ')'])
+            return ''.join([unicode(round(s/1024.0, 1)) , u' KB (',  commafy(s), ')'])
         else:
-            return ''.join([str(round(s/1024.0, 1)) , ' KB'])
+            return ''.join([unicode(round(s/1024.0, 1)) , u' KB'])
+    elif 1048576 < s < 1073741824:
+        if show_bytes:
+            return ''.join([unicode(round(s/1048576.0, 1)), u' MB (',  commafy(s), ')'])
+        else:
+            return ''.join([unicode(round(s/1048576.0, 1)), u' MB'])
     else:
         if show_bytes:
-            return ''.join([str(round(s/1048576.0, 1)), ' MB (',  commafy(s), ')'])
+            return ''.join([unicode(round(s/1073741824.0, 1)), u' GB (',  commafy(s), ')'])
         else:
-            return ''.join([str(round(s/1048576.0, 1)), ' MB'])
-
+            return ''.join([unicode(round(s/1073741824.0, 1)), u' GB'])
+        
 
 
 try:
@@ -491,14 +356,17 @@ except AttributeError:
     def make_temp_file(suffix='', prefix='', dir='', text=False): # pre-2.3
         path = tempfile.mktemp(suffix)
         fd = os.open(path, os.O_RDWR|os.O_CREAT|os.O_EXCL, 0700)
-        #os.unlink( path ) # TODO... make this secure
         return ( os.fdopen( fd, 'w+b' ), path )
-        #return (fd, path)
 
-def log_title(program_name, version):
+def log_title(program_name, version, show_ver=True):
     log.info("")
-    log.info(bold("HP Linux Imaging and Printing System (ver. %s)" % prop.version))
-    log.info(bold("%s ver. %s" % (program_name, version)))
+    
+    if show_ver:
+        log.info(log.bold("HP Linux Imaging and Printing System (ver. %s)" % prop.version))
+    else:    
+        log.info(log.bold("HP Linux Imaging and Printing System"))
+        
+    log.info(log.bold("%s ver. %s" % (program_name, version)))
     log.info("")
     log.info("Copyright (c) 2001-7 Hewlett-Packard Development Company, LP")
     log.info("This software comes with ABSOLUTELY NO WARRANTY.")
@@ -535,91 +403,184 @@ def which(command, return_full_path=False):
         return found_path
 
 
-def deviceDefaultFunctions():
-    cmd_print, cmd_copy, cmd_fax, \
-        cmd_pcard, cmd_scan, cmd_fab = \
-        '', '', '', '', '', ''
-
-    # Print
-    path = which('hp-print')
-
-    if len(path) > 0:
-        cmd_print = 'hp-print -p%PRINTER%'
-    else:
-        path = which('kprinter')
-
+class UserSettings(object):
+    def __init__(self):
+        self.load()
+    
+    def loadDefaults(self):
+        # Print
+        self.cmd_print = ''
+        path = which('hp-print')
+    
         if len(path) > 0:
-            cmd_print = 'kprinter -P%PRINTER% --system cups'
+            self.cmd_print = 'hp-print -p%PRINTER%'
         else:
-            path = which('gtklp')
-
+            path = which('kprinter')
+    
             if len(path) > 0:
-                cmd_print = 'gtklp -P%PRINTER%'
-
+                self.cmd_print = 'kprinter -P%PRINTER% --system cups'
             else:
-                path = which('xpp')
-
+                path = which('gtklp')
+    
                 if len(path) > 0:
-                    cmd_print = 'xpp -P%PRINTER%'
-
-    # Scan
-    path = which('xsane')
-
-    if len(path) > 0:
-        cmd_scan = 'xsane -V %SANE_URI%'
-    else:
-        path = which('kooka')
-
-        if len(path)>0:
-            #cmd_scan = 'kooka -d "%SANE_URI%"'
-            cmd_scan = 'kooka'
-
+                    self.cmd_print = 'gtklp -P%PRINTER%'
+    
+                else:
+                    path = which('xpp')
+    
+                    if len(path) > 0:
+                        self.cmd_print = 'xpp -P%PRINTER%'
+    
+        # Scan
+        self.cmd_scan = ''
+        path = which('xsane')
+    
+        if len(path) > 0:
+            self.cmd_scan = 'xsane -V %SANE_URI%'
         else:
-            path = which('xscanimage')
+            path = which('kooka')
+    
+            if len(path) > 0:
+                self.cmd_scan = 'kooka'
+    
+            else:
+                path = which('xscanimage')
+    
+                if len(path) > 0:
+                    self.cmd_scan = 'xscanimage'
+    
+        # Photo Card
+        path = which('hp-unload')
+    
+        if len(path):
+            self.cmd_pcard = 'hp-unload -d %DEVICE_URI%'
+    
+        else:
+            self.cmd_pcard = 'python %HOME%/unload.py -d %DEVICE_URI%'
+    
+        # Copy
+        path = which('hp-makecopies')
+    
+        if len(path):
+            self.cmd_copy = 'hp-makecopies -d %DEVICE_URI%'
+    
+        else:
+            self.cmd_copy = 'python %HOME%/makecopies.py -d %DEVICE_URI%'
+    
+        # Fax
+        path = which('hp-sendfax')
+    
+        if len(path):
+            self.cmd_fax = 'hp-sendfax -d %FAX_URI%'
+    
+        else:
+            self.cmd_fax = 'python %HOME%/sendfax.py -d %FAX_URI%'
+    
+        # Fax Address Book
+        path = which('hp-fab')
+    
+        if len(path):
+            self.cmd_fab = 'hp-fab'
+    
+        else:
+            self.cmd_fab = 'python %HOME%/fab.py'    
+    
+    def load(self):
+        self.loadDefaults()
+        
+        log.debug("Loading user settings...")
+        
+        self.email_alerts = to_bool(user_cfg.alerts.email_alerts, False)
+        self.email_to_addresses = user_cfg.alerts.email_to_addresses
+        self.email_from_address = user_cfg.alerts.email_from_address
+        self.auto_refresh = to_bool(user_cfg.refresh.enable, False)
 
-            if len(path)>0:
-                cmd_scan = 'xscanimage'
+        try:
+            self.auto_refresh_rate = int(user_cfg.refresh.rate)
+        except ValueError:    
+            self.auto_refresh_rate = 30 # (secs)
 
-    # Photo Card
-    path = which('hp-unload')
-
-    if len(path):
-        cmd_pcard = 'hp-unload -d %DEVICE_URI%'
-
-    else:
-        cmd_pcard = 'python %HOME%/unload.py -d %DEVICE_URI%'
-
-    # Copy
-    path = which('hp-makecopies')
-
-    if len(path):
-        cmd_copy = 'hp-makecopies -d %DEVICE_URI%'
-
-    else:
-        cmd_copy = 'python %HOME%/makecopies.py -d %DEVICE_URI%'
-
-    # Fax
-    path = which('hp-sendfax')
-
-    if len(path):
-        cmd_fax = 'hp-sendfax -d %FAX_URI%'
-
-    else:
-        cmd_fax = 'python %HOME%/sendfax.py -d %FAX_URI%'
-
-    # Fax Address Book
-    path = which('hp-fab')
-
-    if len(path):
-        cmd_fab = 'hp-fab'
-
-    else:
-        cmd_fab = 'python %HOME%/fab.py'
-
-    return cmd_print, cmd_scan, cmd_pcard, \
-           cmd_copy, cmd_fax, cmd_fab
+        try:
+            self.auto_refresh_type = int(user_cfg.refresh.type)
+        except ValueError:
+            self.auto_refresh_type = 0 # refresh 1 (1=refresh all)
 
+        self.cmd_print = user_cfg.commands.prnt or self.cmd_print
+        self.cmd_print_int = to_bool(user_cfg.commands.prnt_int, True)
+        
+        self.cmd_scan = user_cfg.commands.scan or self.cmd_scan
+        self.cmd_scan_int = to_bool(user_cfg.commands.scan_int, False)
+        
+        self.cmd_pcard = user_cfg.commands.pcard or self.cmd_pcard
+        self.cmd_pcard_int = to_bool(user_cfg.commands.pcard_int, True)
+        
+        self.cmd_copy = user_cfg.commands.cpy or self.cmd_copy
+        self.cmd_copy_int = to_bool(user_cfg.commands.cpy_int, True)
+        
+        self.cmd_fax = user_cfg.commands.fax or self.cmd_fax
+        self.cmd_fax_int = to_bool(user_cfg.commands.fax_int, True)
+        
+        self.cmd_fab = user_cfg.commands.fab or self.cmd_fab
+        self.cmd_fab_int = to_bool(user_cfg.commands.fab_int, False)
+        
+        self.debug()
+    
+    def debug(self):
+        log.debug("Print command: %s" % self.cmd_print)
+        log.debug("Use Internal print command: %s" % self.cmd_print_int)
+        
+        log.debug("PCard command: %s" % self.cmd_pcard)
+        log.debug("Use internal PCard command: %s" % self.cmd_pcard_int)
+        
+        log.debug("Fax command: %s" % self.cmd_fax)
+        log.debug("Use internal fax command: %s" % self.cmd_fax_int)
+        
+        log.debug("FAB command: %s" % self.cmd_fab)
+        log.debug("Use internal FAB command: %s" % self.cmd_fab_int)
+        
+        log.debug("Copy command: %s " % self.cmd_copy)
+        log.debug("Use internal copy command: %s " % self.cmd_copy_int)
+        
+        log.debug("Scan command: %s" % self.cmd_scan)
+        log.debug("Use internal scan command: %s" % self.cmd_scan_int)
+        
+        log.debug("Email alerts: %s" % self.email_alerts)
+        log.debug("Email to address(es): %s" % self.email_to_addresses)
+        log.debug("Email from address: %s" % self.email_from_address)
+        log.debug("Auto refresh: %s" % self.auto_refresh)
+        log.debug("Auto refresh rate: %s" % self.auto_refresh_rate)
+        log.debug("Auto refresh type: %s" % self.auto_refresh_type)        
+    
+    def save(self):
+        log.debug("Saving user settings...")
+        
+        user_cfg.commands.prnt = self.cmd_print
+        user_cfg.commands.prnt_int = self.cmd_print_int
+        
+        user_cfg.commands.pcard = self.cmd_pcard
+        user_cfg.commands.pcard_int = self.cmd_pcard_int
+        
+        user_cfg.commands.fax = self.cmd_fax
+        user_cfg.commands.fax_int = self.cmd_fax_int
+        
+        user_cfg.commands.scan = self.cmd_scan
+        user_cfg.commands.scan_int = self.cmd_scan_int
+        
+        user_cfg.commands.cpy = self.cmd_copy
+        user_cfg.commands.cpy_int = self.cmd_copy_int
+        
+        user_cfg.alerts.email_to_addresses = self.email_to_addresses
+        user_cfg.alerts.email_from_address = self.email_from_address
+        user_cfg.alerts.email_alerts = self.email_alerts
+        
+        user_cfg.refresh.enable = self.auto_refresh
+        user_cfg.refresh.rate = self.auto_refresh_rate
+        user_cfg.refresh.type = self.auto_refresh_type
+        
+        self.debug()
+        
 
+          
 def no_qt_message_gtk():
     try:
         import gtk
@@ -682,58 +643,6 @@ def checkPyQtImport():
 
     return True
 
-
-def loadTranslators(app, user_config):
-    #from qt import *
-    import qt
-    loc = None
-
-    if os.path.exists(user_config):
-        # user_config contains executables we will run, so we
-        # must make sure it is a safe file, and refuse to run
-        # otherwise.
-        if not path_exists_safely(user_config):
-            log.warning("File %s has insecure permissions! File ignored." % user_config)
-        else:
-            config = ConfigParser.ConfigParser()
-            config.read(user_config)
-
-            if config.has_section("ui"):
-                loc = config.get("ui", "loc")
-
-                if not loc:
-                    loc = None
-
-    if loc is not None:
-
-        if loc.lower() == 'system':
-            loc = str(qt.QTextCodec.locale())
-
-        if loc.lower() != 'c':
-
-            log.debug("Trying to load .qm file for %s locale." % loc)
-
-            dirs = [prop.home_dir, prop.data_dir, prop.i18n_dir]
-
-            trans = qt.QTranslator(None)
-
-            for dir in dirs:
-                qm_file = 'hplip_%s' % loc
-                loaded = trans.load(qm_file, dir)
-
-                if loaded:
-                    app.installTranslator(trans)
-                    break
-        else:
-            loc = None
-
-    if loc is None:
-        log.debug("Using default 'C' locale")
-    else:
-        log.debug("Using locale: %s" % loc)
-
-    return loc
-
 try:
     from string import Template # will fail in Python <= 2.3
 except ImportError:
@@ -790,7 +699,6 @@ except ImportError:
             self.template = template
 
         # Search for $$, $identifier, ${identifier}, and any bare $'s
-
         def _invalid(self, mo):
             i = mo.start('invalid')
             lines = self.template[:i].splitlines(True)
@@ -905,13 +813,13 @@ def uniqueList(input):
 def list_move_up(l, m):
     for i in range(1, len(l)):
         if l[i] == m:
-            l[i-1],l[i] = l[i],l[i-1]
+            l[i-1], l[i] = l[i], l[i-1]
 
 
 def list_move_down(l, m):
-    for i in range(len(l) - 2, 0, -1):
+    for i in range(len(l)-2, -1, -1):
         if l[i] == m:
-            l[i],l[i+1] = l[i+1],l[i] 
+            l[i], l[i+1] = l[i+1], l[i] 
 
 
 
@@ -980,11 +888,11 @@ class XMLToDictParser:
 
 
  # ------------------------- Usage Help
-
 USAGE_OPTIONS = ("[OPTIONS]", "", "heading", False)
 USAGE_LOGGING1 = ("Set the logging level:", "-l<level> or --logging=<level>", 'option', False)
 USAGE_LOGGING2 = ("", "<level>: none, info\*, error, warn, debug (\*default)", "option", False)
 USAGE_LOGGING3 = ("Run in debug mode:", "-g (same as option: -ldebug)", "option", False)
+USAGE_LOGGING_PLAIN = ("Output plain text only:", "-t", "option", False)
 USAGE_ARGS = ("[PRINTER|DEVICE-URI] (See Notes)", "", "heading", False)
 USAGE_DEVICE = ("To specify a device-URI:", "-d<device-uri> or --device=<device-uri>", "option", False)
 USAGE_PRINTER = ("To specify a CUPS printer:", "-p<printer> or --printer=<printer>", "option", False)
@@ -1046,7 +954,7 @@ def format_text(text_list, typ='text', title='', crumb='', version=''):
             text2 = text2.replace("\\", "")
 
             if format == 'summary':
-                log.info(bold(text1))
+                log.info(log.bold(text1))
                 log.info("")
 
             elif format in ('para', 'name', 'seealso'):
@@ -1056,7 +964,7 @@ def format_text(text_list, typ='text', title='', crumb='', version=''):
                     log.info("")
 
             elif format in ('heading', 'header'):
-                log.info(bold(text1))
+                log.info(log.bold(text1))
 
             elif format in ('option', 'example'):
                 log.info(formatter.compose((text1, text2), trailing_space))
@@ -1340,4 +1248,31 @@ def collapse_range(x): # x --> sorted list of ints
         s.append('-%s' % i)
 
     return ''.join(s)
+    
+def createSequencedFilename(basename, ext, dir=None, digits=3):
+    if dir is None:
+        dir = os.getcwd()
+        
+    m = 0
+    for f in walkFiles(dir, recurse=False, abs_paths=False, return_folders=False, pattern='*', path=None):
+        r, e = os.path.splitext(f)
+        
+        if r.startswith(basename) and ext == e:
+            try:
+                i = int(r[len(basename):])
+            except ValueError:
+                continue
+            else:
+                m = max(m, i)
+                
+    return os.path.join(dir, "%s%0*d%s" % (basename, digits, m+1, ext))
+    
+            
+        
+        
+        
+        
+
+        
+
 
