@@ -51,11 +51,9 @@
 #ifdef TRUE
 #undef TRUE
 #endif
-#include "../../ip/hpip.h"
+#include "hpip.h"
 #include "hpijsfax.h"
 
-extern int bug (const char *fmt, ...);
-
 int hpijsfax_status_cb (void *status_cb_data, IjsServerCtx *ctx, IjsJobId job_id)
 {
     return 0;
@@ -559,7 +557,7 @@ BUGOUT:
 	{
 		fclose (fpFax);
 	}
-    unlink (hpFileName);
+    //unlink (hpFileName);
 	if (pFaxStruct != NULL)
 	{
 		#ifdef CAPTURE
