@@ -2,7 +2,7 @@
 
   hpaio.h - HP SANE backend for multi-function peripherals (libsane-hpaio)
 
-  (c) 2001-2004 Copyright Hewlett-Packard Development Company, LP
+  (c) 2001-2006 Copyright Hewlett-Packard Development Company, LP
 
   Permission is hereby granted, free of charge, to any person obtaining a copy 
   of this software and associated documentation files (the "Software"), to deal 
@@ -21,71 +21,27 @@
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
   WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-  Current Author: Don Welch
-  Original Author: David Paschal 
+  Contributing Authors: David Paschal, Don Welch, David Suffield 
 
 \************************************************************************************/
 
 #if !defined( __HPAIO_H__ )
 #define __HPAIO_H__
 
-#include <stdio.h>
-
-#ifndef __USE_GNU
-#define __USE_GNU
-#endif
-
-#include <sys/time.h>
-#include <time.h>
-#include <string.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <ctype.h>
-
-#define BACKEND_NAME    hpaio
-#define BACKEND_NAME_STR "hpaio"
-#define SANE_DEBUG_BACKENDNAME hpaio
-
 #include "sane.h"
-#include "saneopts.h"
-//#include "sanei_debug.h"
-//#include "sanei_backend.h"
-#include "io.h"
+#include "common.h"
 #include "mfpdtf.h"
-#include "scl.h"
-#include "tables.h"
 #include "hpip.h"
-#include "hplip_api.h"
-
-typedef struct hpaioScanner_s HPAIO_RECORD;
-#include "pml.h"
 
 /************************************************************************************/
 
+#define MAX_DEVICE 64     /* Max devices. */
+
 #define LEN_BUFFER    17408         /* 16384 + 1024, clj28xx used 16396 */
 #define LEN_DEVICE_ID_STRING  4096
 #define LEN_STRING_OPTION_VALUE 20
 #define LEN_MODEL_RESPONSE  20
 
-#define INFINITE_TIMEOUT                ((struct timeval *)0)
-#define SCL_SEND_COMMAND_START_TIMEOUT          0
-#define SCL_SEND_COMMAND_CONTINUE_TIMEOUT       2
-#define SCL_INQUIRE_START_TIMEOUT           30
-#define SCL_INQUIRE_CONTINUE_TIMEOUT            5
-#define SCL_DEVICE_LOCK_TIMEOUT             0
-#define SCL_PREPARE_SCAN_DEVICE_LOCK_MAX_RETRIES    4
-#define SCL_PREPARE_SCAN_DEVICE_LOCK_DELAY      1
-#define PML_SELECT_POLL_TIMEOUT             1
-#define PML_UPLOAD_TIMEOUT              45
-#define PML_START_SCAN_WAIT_ACTIVE_MAX_RETRIES      40
-#define PML_START_SCAN_WAIT_ACTIVE_DELAY        1
-#define MFPDTF_EARLY_READ_TIMEOUT           60
-#define MFPDTF_LATER_READ_TIMEOUT           20
-#define NON_MFPDTF_READ_START_TIMEOUT           60
-#define NON_MFPDTF_READ_CONTINUE_TIMEOUT        2
-
 #define PAD_VALUE_LINEART            0
 #define PAD_VALUE_GRAYSCALE_COLOR    -1
 
@@ -103,7 +59,7 @@ enum hpaioOption_e {
                     OPTION_JPEG_COMPRESSION_FACTOR,
                     OPTION_BATCH_SCAN,
                     OPTION_ADF_MODE, 
-                    OPTION_DUPLEX,
+//                    OPTION_DUPLEX,
 
     GROUP_GEOMETRY,
                     OPTION_LENGTH_MEASUREMENT,
@@ -114,9 +70,9 @@ enum hpaioOption_e {
 
     OPTION_LAST };
 
-#define STR_SCAN_MODE_LINEART "Lineart"
-#define STR_SCAN_MODE_GRAYSCALE "Grayscale"
-#define STR_SCAN_MODE_COLOR "Color"
+//#define STR_SCAN_MODE_LINEART "Lineart"
+//#define STR_SCAN_MODE_GRAYSCALE "Grayscale"
+//#define STR_SCAN_MODE_COLOR "Color"
 
 enum hpaioScanMode_e { SCAN_MODE_FIRST = 0,
                        SCAN_MODE_LINEART = 0,
@@ -131,24 +87,9 @@ enum hpaioScanMode_e { SCAN_MODE_FIRST = 0,
 #define COMPRESSION_MMR   0x08
 #define COMPRESSION_JPEG  0x10
 
-#define STR_COMPRESSION_NONE  "None"
-#define STR_COMPRESSION_MH  "MH"
-#define STR_COMPRESSION_MR  "MR"
-#define STR_COMPRESSION_MMR "MMR"
-#define STR_COMPRESSION_JPEG  "JPEG"
-
-#define MIN_JPEG_COMPRESSION_FACTOR 0
-#define MAX_JPEG_COMPRESSION_FACTOR 100
-/* To prevent "2252" asserts on OfficeJet 600 series: */
-#define SAFER_JPEG_COMPRESSION_FACTOR 10
-
-#define ADF_MODE_AUTO   0x01
-#define ADF_MODE_FLATBED  0x02
-#define ADF_MODE_ADF    0x04
-
-#define STR_ADF_MODE_AUTO "Auto"
-#define STR_ADF_MODE_FLATBED  "Flatbed"
-#define STR_ADF_MODE_ADF  "ADF"
+#define ADF_MODE_AUTO   0x01     /* flatbed or ADF */
+#define ADF_MODE_FLATBED  0x02   /* flatbed only */
+#define ADF_MODE_ADF    0x04     /* ADF only */
 
 #define LENGTH_MEASUREMENT_UNKNOWN    0
 #define LENGTH_MEASUREMENT_UNLIMITED    1
@@ -156,66 +97,13 @@ enum hpaioScanMode_e { SCAN_MODE_FIRST = 0,
 #define LENGTH_MEASUREMENT_PADDED   3
 #define LENGTH_MEASUREMENT_EXACT    4
 
-#define STR_LENGTH_MEASUREMENT_UNKNOWN    "Unknown"
-#define STR_LENGTH_MEASUREMENT_UNLIMITED  "Unlimited"
-#define STR_LENGTH_MEASUREMENT_APPROXIMATE  "Approximate"
-#define STR_LENGTH_MEASUREMENT_PADDED   "Padded"
-#define STR_LENGTH_MEASUREMENT_EXACT    "Exact"
-
-#define STR_UNKNOWN   "???"
-
-#define GEOMETRY_OPTION_TYPE    SANE_TYPE_FIXED
-#define MILLIMETER_SHIFT_FACTOR   SANE_FIXED_SCALE_SHIFT
-
-#define DECIPOINTS_PER_INCH     720
-#define DEVPIXELS_PER_INCH      300
-#define MILLIMETERS_PER_10_INCHES   254
-#define INCHES_PER_254_MILLIMETERS  10
-
-#define BYTES_PER_LINE(pixelsPerLine,bitsPerPixel) \
-    ((((pixelsPerLine)*(bitsPerPixel))+7)/8)
-
-#define INCHES_TO_MILLIMETERS(inches) \
-    DivideAndShift(__LINE__, \
-    (inches), \
-    MILLIMETERS_PER_10_INCHES, \
-    INCHES_PER_254_MILLIMETERS, \
-    MILLIMETER_SHIFT_FACTOR)
-
-#define DECIPIXELS_TO_MILLIMETERS(decipixels) \
-    DivideAndShift(__LINE__, \
-    (decipixels), \
-    MILLIMETERS_PER_10_INCHES, \
-    INCHES_PER_254_MILLIMETERS*hpaio->decipixelsPerInch, \
-    MILLIMETER_SHIFT_FACTOR)
-
-#define MILLIMETERS_TO_DECIPIXELS(millimeters) \
-    DivideAndShift(__LINE__, \
-    (millimeters), \
-    INCHES_PER_254_MILLIMETERS*hpaio->decipixelsPerInch, \
-    MILLIMETERS_PER_10_INCHES, \
-    -MILLIMETER_SHIFT_FACTOR)
-
-#define PIXELS_TO_MILLIMETERS(pixels,pixelsPerInch) \
-    DivideAndShift(__LINE__, \
-    (pixels), \
-    MILLIMETERS_PER_10_INCHES, \
-    (pixelsPerInch)*INCHES_PER_254_MILLIMETERS, \
-    MILLIMETER_SHIFT_FACTOR)
-
-#define MILLIMETERS_TO_PIXELS(millimeters,pixelsPerInch) \
-    DivideAndShift(__LINE__, \
-    (millimeters), \
-    INCHES_PER_254_MILLIMETERS*(pixelsPerInch), \
-    MILLIMETERS_PER_10_INCHES, \
-    -MILLIMETER_SHIFT_FACTOR)
-
 struct  hpaioScanner_s
 {
+        char *tag;   /* handle identifier */
         char deviceuri[128];
-        int deviceid;
-        int scan_channelid;
-        int cmd_channelid;
+        HPMUD_DEVICE deviceid;
+        HPMUD_CHANNEL scan_channelid;
+        HPMUD_CHANNEL cmd_channelid;
         
         struct hpaioScanner_s * prev;
         struct hpaioScanner_s * next;
@@ -367,14 +255,6 @@ typedef struct hpaioScanner_s * hpaioScanner_t;
   } while(0)
 #define SET_DEFAULT_MODEL(hpaio,s) _SET_DEFAULT_MODEL(hpaio,s,strlen(s))
 
-#define ADD_XFORM(x) \
-  do { \
-    pXform->eXform=x; \
-    DBG( 0, "hpaio:%s: sane_hpaio_start: added xform=%d.\n", \
-      hpaio->saneDevice.name,pXform->eXform); \
-    pXform++; \
-  } while(0)
-
 #define FIX_GEOMETRY(low,high,min,max) \
   do { \
     if (high<low) high=low; \
@@ -387,7 +267,8 @@ typedef struct hpaioScanner_s * hpaioScanner_t;
     } \
   } while(0)
 
-SANE_Status hpaioScannerToSaneStatus( hpaioScanner_t hpaio );
-SANE_Status hpaioScannerToSaneError( hpaioScanner_t hpaio );
+SANE_Status __attribute__ ((visibility ("hidden"))) hpaioScannerToSaneStatus( hpaioScanner_t hpaio );
+SANE_Status __attribute__ ((visibility ("hidden"))) hpaioScannerToSaneError( hpaioScanner_t hpaio );
+void sane_hpaio_cancel(SANE_Handle handle);
 
 #endif
